inif.selectors

TokenSelection container; selection methods live on Sample / InifDocument.

The selection container TokenSelection is exported from this module. The actual selection verbs are methods on Sample (.select_by_position, .select_by_annotation, .select_by_sequence_id, .select_by_span) and on InifDocument (.filter_samples, .filter_samples_by_score, .subset).

See Selecting tokens and samples for the narrative overview.

Selection container