inif.viewer

HTML viewer implementations powering InifDocument.render_html / .save_html / .show.

The viewer is exposed as three methods on InifDocumentrender_html(), save_html(path), and show(). The implementations live in this module.

See HTML viewer for what the rendered page looks like and the available options.